intervaltreetools.group_overlapping_intervals_and_yield_groups
==============================================================

.. autofunction:: abjad.tools.intervaltreetools.group_overlapping_intervals_and_yield_groups
